.trx-addons-restaurant-menu .trx-addons-restaurant-menu-item-wrap {
	position: relative;
}
.trx-addons-restaurant-menu .trx-addons-restaurant-menu-item-wrap + .trx-addons-restaurant-menu-item-wrap {
	margin-top: 10px;
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-item {
	display: flex;
	align-items: center;
}
@media screen and (max-width: 767px) {
	.trx-addons-restaurant-menu {
		.trx-addons-restaurant-menu-item {
			flex-direction: column;
			justify-content: flex-start;
			align-items: flex-start;
		}
		.trx-addons-restaurant-menu-content {
			width: 100%;
		}
	}
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-image {
	flex-grow: 0;
	flex-shrink: 0;
	margin-right: 10px;
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-content {
	flex-grow: 1;
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-header {
	display: flex;
	justify-content: space-between;
	margin-bottom: 5px;
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-title {
	display: inline-block;
	vertical-align: top;
	margin: 0;
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-title a {
	color: inherit;
}

.trx-addons-restaurant-menu-style-0 .trx-addons-restaurant-menu-content {
	padding-bottom: 3.5em;
}

.trx-addons-restaurant-menu-style-1 .trx-addons-restaurant-menu-price {
	float: right;
}

.trx-addons-restaurant-menu-style-3 .trx-addons-restaurant-menu-image {
	order: 1;
}

.trx-addons-restaurant-menu-style-4 .trx-addons-restaurant-menu-item,
.trx-addons-restaurant-menu-style-4 .trx-addons-restaurant-menu-header {
	display: block;
}

.trx-addons-restaurant-menu-style-4 .trx-addons-restaurant-menu-image {
	display: inline-block;
}

.trx-addons-restaurant-menu-style-1 .trx-addons-price-title-connector {
	border-bottom: 1px dashed #000;
	height: 1px;
	flex-grow: 1;
	align-self: center;
	margin: 0 20px;
	position: relative;
}

.trx-addons-restaurant-menu-style-0 .trx-addons-restaurant-menu-item {
	min-height: 150px;
	position: relative;
}

.trx-addons-restaurant-menu-style-0 .trx-addons-restaurant-menu-price {
	position: absolute;
	bottom: 0;
	right: 0;
	z-index: 1;
	padding: 10px;
}

.trx-addons-restaurant-menu-style-0 .trx-addons-restaurant-menu-price:after {
	content: " ";
	position: absolute;
	bottom: 0;
	right: 0;
	z-index: -1;
	border-color: transparent #B83D11;
	border-style: solid;
	border-width: 110px 130px 0 0;
}

.trx-addons-restaurant-menu .trx-addons-restaurant-menu-price-original {
	display: inline-block;
	vertical-align: baseline;
}

.trx-addons-restaurant-menu-divider-wrap {
	font-size: 0;
	line-height: 0;
}

.trx-addons-restaurant-menu-divider {
	display: inline-block;
	vertical-align: top;
}