<?php
/**
 * Base class (Singleton)
 *
 * @package ThemeREX Addons
 * @since v2.30.0
 */

namespace TrxAddons\ElementorWidgets;

defined( 'ABSPATH' ) || exit;

use \TrxAddons\Core\Singleton;

class Base extends Singleton {
}
