.trx-addons-testimonials-box {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  width: 100%;
  background: transparent;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.trx-addons-testimonials-box h1, .trx-addons-testimonials-box h2, .trx-addons-testimonials-box h3, .trx-addons-testimonials-box h4, .trx-addons-testimonials-box h5, .trx-addons-testimonials-box h6, .trx-addons-testimonials-box p {
  letter-spacing: 0;
  margin: 0;
}

.trx-addons-testimonials-equal-height-yes .trx-addons-testimonials-content-wrapper {
  height: 100%;
}

.trx-addons-testimonials-carousel {
  display: block;
  width: 100%;
}

.trx-addons-testimonials-author-info {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

.trx-addons-testimonials-heading,
.trx-addons-testimonials-person-name,
.trx-addons-testimonials-company {
  color: #212121;
}

.trx-addons-testimonials-text-wrapper {
  margin-bottom: 10px;
}

.trx-addons-testimonials-box .trx-addons-testimonials-heading {
  margin-bottom: 10px;
}
.trx-addons-testimonials-box .trx-addons-testimonials-person-name {
  margin-bottom: 5px;
}
.trx-addons-testimonials-box .trx-addons-testimonials-company {
  margin-bottom: 5px;
}

.trx-addons-testimonials-container {
  position: relative;
  width: 100%;
}

.trx-addons-testimonials-img-wrapper {
  overflow: hidden;
  border-radius: 50%;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.trx-addons-testimonials-img-wrapper img {
  object-fit: cover;
  width: 100%;
  height: 100% !important;
  border-radius: 50%;
}

.trx-addons-testimonials__img-info {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.trx-addons-testimonials-content-wrapper {
  position: relative;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  width: 100%;
  padding: 20px;
}

.trx-addons-testimonials-clear-float {
  clear: both;
}

.trx-addons-testimonials-upper-quote {
  position: absolute;
  z-index: 1;
  top: 3px;
  left: 3px;
}

.trx-addons-testimonials-lower-quote {
  position: absolute;
  z-index: 1;
  bottom: 3px;
  right: 3px;
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}

.trx-addons-testimonials-rating-position-hide .trx-addons-testimonials__rating-wrapper {
  display: none;
}

.trx-addons-testimonials-rating-position-before .trx-addons-testimonials-heading {
  -webkit-order: 2;
  -ms-flex-order: 2;
  order: 2;
}
.trx-addons-testimonials-rating-position-before .trx-addons-testimonials__rating-wrapper {
  -webkit-order: 3;
  -ms-flex-order: 3;
  order: 3;
}
.trx-addons-testimonials-rating-position-before .trx-addons-testimonials-text-wrapper {
  -webkit-order: 4;
  -ms-flex-order: 4;
  order: 4;
}

.trx-addons-testimonials-rating-position-after .trx-addons-testimonials-heading {
  -webkit-order: 2;
  -ms-flex-order: 2;
  order: 2;
}
.trx-addons-testimonials-rating-position-after .trx-addons-testimonials-text-wrapper {
  -webkit-order: 3;
  -ms-flex-order: 3;
  order: 3;
}
.trx-addons-testimonials-rating-position-after .trx-addons-testimonials__rating-wrapper {
  -webkit-order: 4;
  -ms-flex-order: 4;
  order: 4;
}

.trx-addons-testimonials__skin1 .trx-addons-testimonials__img-info {
  -webkit-order: 5;
  -ms-flex-order: 5;
  order: 5;
}

.trx-addons-testimonials__skin2 .trx-addons-testimonials__img-info {
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
}

.trx-addons-testimonials__skin3 .trx-addons-testimonials-img-wrapper {
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
}
.trx-addons-testimonials__skin3 .trx-addons-testimonials-author-info {
  -webkit-order: 5;
  -ms-flex-order: 5;
  order: 5;
}

/*# sourceMappingURL=Testimonials.css.map */
