:root {
  --trx-addons-base-size: 1;
}

.trx-addons-advanced-title {
  position: relative;
  margin: 0;
}

.trx-addons-advanced-title-link {
  display: block;
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}

.elementor-widget-trx_elm_advanced_title.trx-addons-animate .trx-addons-svg-wrapper path {
  stroke-dasharray: 1500;
  animation: highlighted-line 2s cubic-bezier(0.29, 1.11, 0.74, 1.04) forwards;
  animation-play-state: paused;
}

.trx-addons-advanced-title-item {
  display: inline-block;
  position: relative;
}
.trx-addons-advanced-title-item:not(:last-child) {
  margin-right: 0.15em;
}
.trx-addons-advanced-title-item[class*="trx-addons-advanced-title-stroke"] {
  padding-left: 0.1em;
  padding-right: 0.1em;
}

.trx-addons-advanced-title-item-text {
  position: relative;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}

.trx-addons-advanced-title-item-highlighted .trx-addons-advanced-title-text {
  position: relative;
  z-index: 1;
}

.trx-addons-advanced-title-item-text svg {
  position: absolute;
  top: auto;
  left: 50%;
  width: 106%;
  height: 100%;
  transform: translate(-50%);
  overflow: visible;
}

.trx-addons-advanced-title-item-text svg path {
  stroke-width: 9;
  fill: none;
  -webkit-transition: stroke 0.3s ease, fill 0.3s ease;
  -ms-transition: stroke 0.3s ease, fill 0.3s ease;
  transition: stroke 0.3s ease, fill 0.3s ease;
}

.trx-addons-advanced-title-item-text[class*="trx-addons-advanced-title-stroke"] {
  white-space: nowrap;
}

.trx-addons-advanced-title-item-icon svg,
.trx-addons-advanced-title-item-image img {
  vertical-align: middle;
  max-height: calc( 0.88em * var(--trx-addons-base-size, 1) );
  width: auto;
  margin-bottom: .2em;
}

.trx-addons-advanced-title-item-image img {
  -webkit-box-sizing: content-box;
  -ms-box-sizing: content-box;
  box-sizing: content-box;
  -webkit-transition: background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: background-color 0.3s ease, border-color 0.3s ease;
  transition: background-color 0.3s ease, border-color 0.3s ease;
}

.trx-addons-advanced-title-item-icon i {
  vertical-align: middle;
  font-size: calc( 0.88em * var(--trx-addons-base-size, 1) );
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}

@keyframes highlighted-line {
  from {
    stroke-dasharray: 0 1500;
  }
  to {
    stroke-dasharray: 1500 1500;
  }
}

/*# sourceMappingURL=AdvancedTitle.css.map */
