#elementor-panel-category-trx-addons .icon {
    max-height: 43px;
}
.elementor-element [class*="trx-addons-"]:after {
    background: transparent;
    border-width: 0 1px 1px 0;
    border-color: #e0e0e0;
    border-style: solid;
    content: "PP";
    font-family: Roboto,Arial,Helvetica,Verdana,sans-serif;
    font-size: 9px;
    position: absolute;
    top: 0;
    left: 0;
    padding: 0.2em 0.5em;
}
#elementor-panel-elements-wrapper .elementor-element:hover .trx-addons-admin-icon:after {
    background: #d30c5c;
    border-color: #d30c5c;
    color: #fff;
}
.elementor-control-layout.elementor-control-type-choose.elementor-control-separator-none .elementor-control-input-wrapper {
    display: flex;
    border-bottom: 1px solid #d5dadf;
	border-right: 1px solid #d5dadf;
    border-radius: 2px;
    overflow: hidden
}
.elementor-control-layout.elementor-control-type-choose.elementor-control-separator-none .elementor-control-input-wrapper .elementor-choices {
    display: flex;
    height: auto;
    flex-wrap: wrap;
    align-items: stretch;
    background: #fff;
    margin-bottom: -1px;
}
.elementor-control-layout.elementor-control-type-choose.elementor-control-separator-none .elementor-control-input-wrapper .elementor-choices .elementor-choices-label {
    border-bottom: 0;
    border-radius: 0;
    box-sizing: border-box;
    flex: auto;
    font-size: 25px;
    padding: 7px 0;
    width: 33.33333%;
}
.elementor-control-layout.elementor-control-type-choose.elementor-control-separator-none .elementor-control-input-wrapper .elementor-choices .elementor-choices-label:nth-of-type(3n) {
    border-right: none
}
.elementor-control-layout.elementor-control-type-choose.elementor-control-separator-none .elementor-control-input-wrapper .elementor-choices input:checked+.elementor-choices-label {
    background: #a4afb7;
}
.elementor-control-arrow.elementor-control-type-choose .elementor-choices {
	border-radius: 0;
	flex-wrap: wrap;
	height: auto;
}
.elementor-control-arrow.elementor-control-type-choose .elementor-choices label {
	border-right-width: 1px;
    border-right-style: solid;
	border-radius: 0;
    margin-right: 3px;
	margin-bottom: 3px;
	width: 40px;
}
.elementor-control-type-trx-addons-query .elementor-control-input-wrapper,
.elementor-control-type-select2.elementor-label-inline .elementor-control-input-wrapper,
.elementor-control-sticky_toc_disable_on .elementor-control-input-wrapper,
.elementor-control-email_metadata .elementor-control-input-wrapper,
.elementor-control-toolbar_buttons .elementor-control-input-wrapper {
    width: 135px;
}
.trx-addons-editor-info {
    background-color: #fcf8e3;
    border: 1px solid #faebcc;
	color: #8a6d3b;
	font-size: 12px;
	line-height: 1.3;
	padding: 10px;
}
.trx-addons-editor-doc-links {
	font-size: 12px;
}
.trx-addons-editor-doc-links a {
	color: #6d7882;
	display: inline-block;
	line-height: 1.2;
	padding-left: 10px;
	position: relative;
}
.trx-addons-editor-doc-links a:before {
	content: '»';
	position: absolute;
	left: 0;
	top: 0;
}
.trx-addons-editor-placeholder {
	background: #f5f5f5;
	border: 1px solid #ddd;
    padding: 15px;
	text-align: center
}
.trx-addons-editor-placeholder-title {
	color: #222;
	font-size: 18px;
	line-height: 1.4;
	margin-bottom: 10px;
}
.trx-addons-editor-placeholder-content {
	color: #666;
	font-size: 12px;
}

/* Template Library */
#elementor-template-library-templates[data-template-source="powerpack"] #elementor-template-library-templates-container {
	margin: 10px -15px 0;
}

/* Flip Box Widget */
.elementor-widget-trx-addons-flipbox.trx-addons-flip-box--flipped .elementor-widget-container .trx-addons-flipbox-front {
	display: none;
}

.elementor-widget-trx-addons-flipbox.trx-addons-flip-box--flipped .elementor-widget-container .trx-addons-flipbox-back {
	transform: none !important;
	transition: unset !important;
	opacity: 1;
}

.elementor-widget-trx-addons-flipbox.trx-addons-flip-box--flipped .elementor-widget-container .trx-addons-flipbox-flip-card {
	transition: unset !important;
	transform: none !important;
}